dos2unix(1)                                                        dos2unix(1)



NAME
       dos2unix - DOS/MAC to UNIX text file format converter


SYNOPSYS
       dos2unix  [options] [-c convmode] [-o file ...] [-n infile outfile ...]

       Options:

       [-hkqLV] [--help] [--keepdate] [--quiet] [--license] [--version]


DESCRIPTION
       Dos2unix converts plain text files in DOS/MAC format to UNIX format.

       Dos2unix  has  a  few  conversion  modes  similar  to  dos2unix   under
       SunOS/Solaris.

       In  DOS/Windows  text  files line endings exist out of a combination of
       two characters: a Carriage Return (CR) followed by a  Line  Feed  (LF).
       In  Unix text files line endings exists out of a single Newline charac-
       ter which is equal to a DOS Line Feed  (LF)  character.   In  Mac  text
       files,  prior  to Mac OS X, line endings exist out of a single Carriage
       Return character. Mac OS X is Unix based and has the same line  endings
       as Unix.


OPTIONS
       The following options are available:


       -c --convmode convmode
              Set conversion mode. Where convmode is one of: ASCII, 7bit, ISO,
              Mac with ASCII being the default.


       -h --help
              Print online help.


       -k --keepdate
              Keep the date stamp of output file same as input file.


       -L --license
              Print software license.


       -n --newfile infile outfile ...
              New file mode. Convert the infile and write output  to  outfile.
              File  names must be given in pairs and wildcard names should NOT
              be used or you WILL lose your files.


       -o --oldfile file ...
              Old file mode. Convert the file and write output to it. The pro-
              gram default to run in this mode. Wildcard names may be used.


       -q --quiet
              Quiet mode. Suppress all warning and messages.


       -V --version
              Print version information.

CONVERSION MODES
       Conversion  modes  ASCII  ,  7bit  ,  and  ISO  are similar to those of
       dos2unix under SunOS/Solaris.


       ASCII  In this mode DOS line endings are converted to  Unix  line  end-
              ings.

              Although  the name of this mode is ASCII, which is a 7 bit stan-
              dard, the actual mode is 8 bit.


       Mac    In this mode Mac line endings are converted to  Unix  line  end-
              ings.


       7bit   In  this  mode  DOS line endings are converted to Unix line end-
              ings.  All 8 bit non-ASCII characters (with values from  128  to
              255) are converted to a space.


       ISO    In  this  mode  DOS line endings are converted to Unix line end-
              ings.  Characters are converted from  DOS  character  set  (code
              page)  CP437  to  ISO character set ISO-8859-1. CP437 characters
              without ISO-8859-1 equivalent, for which conversion is not  pos-
              sible, are converted to a wrong, but unique, ISO character. This
              means that if the converted file is converted back to  DOS  with
              unix2dos(1)  in  ISO mode, you get exactly the same file back as
              the original.  So you can convert forth and back without loss of
              original  text. The down side is that you may find strange char-
              acters in the converted file.  CP437 is mainly used in the  USA.
              In Western Europe CP850 is more standard.

              Another option to convert text files between different encodings
              is to use dos2unix in combination with iconv(1). Iconv can  con-
              vert between a long list of character encodings. Some examples:

              Convert from DOS DOSLatinUS to Unix Latin-1

              iconv -f CP437 -t ISO-8859-1 in.txt | dos2unix > out.txt

              Convert from DOS DOSLatin1 to Unix Latin-1

              iconv -f CP850 -t ISO-8859-1 in.txt | dos2unix > out.txt

              Convert from Windows WinLatin1 to Unix Latin-1

              iconv -f CP1252 -t ISO-8859-1 in.txt | dos2unix > out.txt

              Convert from Windows WinLatin1 to Unix UTF-8 (Unicode)

              iconv -f CP1252 -t UTF-8 in.txt | dos2unix > out.txt

              See also <http://czyborra.com/charsets/codepages.html>
              and <http://czyborra.com/charsets/iso8859.html>.


EXAMPLES
       Get input from stdin and write output to stdout.

              dos2unix


       Convert and replace a.txt. Convert and replace b.txt.

              dos2unix a.txt b.txt

              dos2unix -o a.txt b.txt


       Convert and replace a.txt in ASCII conversion mode.

              dos2unix a.txt


       Convert  and  replace  a.txt  in  ASCII  conversion  mode.  Convert and
       replace b.txt in 7bit conversion mode.

              unix2dos a.txt -c 7bit b.txt

              unix2dos -c ascii a.txt -c 7bit b.txt


       Convert a.txt from Mac to Unix format.

              dos2unix -c mac a.txt

              mac2unix a.txt


       Convert and replace a.txt while keeping original date stamp.

              dos2unix -k a.txt

              dos2unix -k -o a.txt


       Convert a.txt and write to e.txt.

              dos2unix -n a.txt e.txt


       Convert a.txt and write to e.txt, keep date  stamp  of  e.txt  same  as
       a.txt.

              dos2unix -k -n a.txt e.txt


       Convert and replace a.txt. Convert b.txt and write to e.txt.

              dos2unix a.txt -n b.txt e.txt

              dos2unix -o a.txt -n b.txt e.txt


       Convert  c.txt  and write to e.txt. Convert and replace a.txt.  Convert
       and replace b.txt. Convert d.txt and write to f.txt.

              dos2unix -n c.txt e.txt -o a.txt b.txt -n d.txt f.txt


AUTHORS
       Benjamin Lin - <blin@socs.uts.edu.au>

       Bernd Johannes Wuebben (mac2unix mode) - <wuebben@kde.org>

       Erwin Waterlander - <waterlan@xs4all.nl>

       Project page: http://www.xs4all.nl/~waterlan/#DOS2UNIX

       SourceForge page: http://sourceforge.net/projects/dos2unix/

       Freshmeat: http://freshmeat.net/projects/dos2unix


SEE ALSO
       unix2dos(1) mac2unix(1) iconv(1)




2009                            dos2unix 4.0.1                     dos2unix(1)
